@@ -1,10 +1,7 @@
-library(pbdPROF, quiet = TRUE)
+suppressMessages(library(pbdPROF, quietly = TRUE))
 
 fn <- system.file("extdata/svd.fpmpi", package = "pbdPROF")
 da <- read.prof(fn)
 
 print(da)
 
-if (interactive()){
-  plot(da)
-}
